/*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

PURPOSE: Helper programs to generate nice tables and attach labels

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/


// Program to store ttest results by category dummy
capt prog drop diffTest
program diffTest, eclass
  syntax varlist [if] [in], by(varname) [ * ]
  marksample touse
  markout `touse' `by'
  tempname N_1 N_2 sd_1 sd_2 mu_1 mu_2 d d_se d_t d_p
  foreach var of local varlist {
      qui ttest `var' if `touse', by(`by') `options'
      mat `N_1' = nullmat(`N_1'), r(N_1)
      mat `N_2' = nullmat(`N_2'), r(N_2)
      mat `mu_1' = nullmat(`mu_1'), r(mu_1)
      mat `mu_2' = nullmat(`mu_2'), r(mu_2)
      mat `sd_1' = nullmat(`sd_1'), r(sd_1)
      mat `sd_2' = nullmat(`sd_2'), r(sd_2)
      mat `d'    = nullmat(`d'   ), r(mu_2)-r(mu_1)
      mat `d_se' = nullmat(`d_se'), r(se)
      mat `d_t'  = nullmat(`d_t' ), r(t)
      mat `d_p'  = nullmat(`d_p' ), r(p)
  }
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p {
      mat coln ``mat'' = `varlist'
  }
  tempname b V
  mat `b' = `mu_1'*0
  mat `V' = `b''*`b'
  eret post `b' `V'
  eret local cmd "meanDiffTable"
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p {
      eret mat `mat' = ``mat''
  }
  tempname N1 N2 
  scalar `N1' = `N_1'[1,1]
  scalar `N2' = `N_2'[1,1]
  foreach sca in N1 N2 {
      eret sca `sca' = ``sca''
  }
end

// same as above, but allows for different samples
capt prog drop diffTestDiffSamp
program diffTestDiffSamp, eclass
  syntax varlist [if] [in], by(varname) [ * ]
  tempname N_1 N_2 sd_1 sd_2 mu_1 mu_2 d d_se d_t d_p
  foreach var of local varlist {
      qui ttest `var', by(`by') `options'
      mat `N_1' = nullmat(`N_1'), r(N_2)
      mat `N_2' = nullmat(`N_2'), r(N_1)
      mat `mu_1' = nullmat(`mu_1'), r(mu_2)
      mat `mu_2' = nullmat(`mu_2'), r(mu_1)
      mat `sd_1' = nullmat(`sd_1'), r(sd_2)
      mat `sd_2' = nullmat(`sd_2'), r(sd_1)
      mat `d'    = nullmat(`d'   ), r(mu_2)-r(mu_1)
      mat `d_se' = nullmat(`d_se'), r(se)
      mat `d_t'  = nullmat(`d_t' ), r(t)
      mat `d_p'  = nullmat(`d_p' ), r(p)
  }
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p {
      mat coln ``mat'' = `varlist'
  }
  tempname b V
  mat `b' = `mu_1'*0
  mat `V' = `b''*`b'
  eret post `b' `V'
  eret local cmd "meanDiffTable"
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p {
      eret mat `mat' = ``mat''
  }
  tempname N1 N2 
  scalar `N1' = `N_1'[1,1]
  scalar `N2' = `N_2'[1,1]
  foreach sca in N1 N2 {
      eret sca `sca' = ``sca''
  }
end

// Program to display ttest results in a nice table
capt prog drop ttestTable
program define ttestTable
  args TABVARS BYVAR TABFILE TITLE LABEL HEAD1 HEAD2 HEAD3
  diffTestDiffSamp `TABVARS', by(`BYVAR')
  esttab using `TABFILE'.tex, title(`TITLE'\label{tab:`LABEL'}) nomtitles nonumbers collabels("`HEAD1'" "`HEAD2'" "`HEAD3'") varwidth(32) label replace booktabs cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)") star(* 0.10 ** 0.05 *** 0.01) stats(N1 N2, labels(Observations) layout("@ @")) addnote("* p lt 0.10, ** p lt 0.05, *** p lt 0.01") 
end

capt prog drop ttestTableAtt
program define ttestTableAtt
  args TABVARS BYVAR TABFILE TITLE LABEL HEAD1 HEAD2 HEAD3
  diffTestDiffSamp `TABVARS', by(`BYVAR')
  esttab using `TABFILE'.tex, title(`TITLE'\label{tab:`LABEL'}) nomtitles nonumbers collabels("`HEAD1'" "`HEAD2'" "`HEAD3'") varwidth(32) label replace booktabs cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)") star(* 0.10 ** 0.05 *** 0.01) noobs addnote("* p lt 0.10, ** p lt 0.05, *** p lt 0.01") 
end

capt prog drop ttestTableCSV
program define ttestTableCSV
  args TABVARS BYVAR TABFILE TITLE LABEL HEAD1 HEAD2 HEAD3
  diffTest `TABVARS', by(`BYVAR')
  esttab using `TABFILE'.csv, title(`TITLE') nomtitles nonumbers collabels(`HEAD1' `HEAD2' `HEAD3') varwidth(32) label replace cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)") star(* 0.10 ** 0.05 *** 0.01) stats(N1 N2, labels(Observations)) addnote("* p lt 0.10, ** p lt 0.05, *** p lt 0.01") 
end


// Program to store ttest results by action dummy
capt prog drop diffTest2
program diffTest2, eclass
  syntax varlist [if] [in], by(varname) [ * ]
  marksample touse
  markout `touse' `by'
  tempname N_1 N_2 sd_1 sd_2 mu_1 mu_2 d d_se d_t d_p se_1 se_2
  foreach var of local varlist {
      qui ttest `var', by(`by') `options'
      mat `N_1' = nullmat(`N_1'), r(N_2)
      mat `N_2' = nullmat(`N_2'), r(N_1)
      mat `mu_1' = nullmat(`mu_1'), r(mu_2)
      mat `mu_2' = nullmat(`mu_2'), r(mu_1)
      mat `sd_1' = nullmat(`sd_1'), r(sd_2)
      mat `sd_2' = nullmat(`sd_2'), r(sd_1)
      mat `d'    = nullmat(`d'   ), r(mu_2)-r(mu_1)
      mat `d_se' = nullmat(`d_se'), r(se)
      mat `d_t'  = nullmat(`d_t' ), r(t)
      mat `d_p'  = nullmat(`d_p' ), r(p)
	  qui tabstat `var', by(`by') stats(semean) save
	  mat `se_1' = nullmat(`se_1'), r(Stat2)
	  mat `se_2' = nullmat(`se_2'), r(Stat1)
  }
  foreach mat in N_1 N_2 mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p se_1 se_2 {
      mat coln ``mat'' = `varlist'
  }
  tempname b V
  mat `b' = `mu_1'*0
  mat `V' = `b''*`b'
  eret post `b' `V'
  eret local cmd "meanDiffTable"
  foreach mat in N_1 N_2 mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p se_1 se_2 {
      eret mat `mat' = ``mat''
  }
end

capt prog drop qregStats
program qregStats, eclass
	syntax varlist, by(varname)
	marksample touse
	markout `touse' `by'
	tempname ctl ctl_se ctl_n ctl_p trt trt_se trt_p trt_n diff diff_se diff_p
	foreach var of local varlist {
		qui qreg `var' `by'
			mat `ctl'		= nullmat(`ctl'   ), _b[_cons]
			mat `ctl_se'	= nullmat(`ctl_se'), _se[_cons]
			mat `ctl_p'		= nullmat(`ctl_p'), 2*min(ttail(e(df_r),_b[_cons]/_se[_cons]),1-ttail(e(df_r),_b[_cons]/_se[_cons]))
			mat `diff'		= nullmat(`diff'), _b[`by']
			mat `diff_se'	= nullmat(`diff_se'), _se[`by']
			mat `diff_p'	= nullmat(`diff_p'), 2*min(ttail(e(df_r),_b[`by']/_se[`by']),1-ttail(e(df_r),_b[`by']/_se[`by']))
		qui lincom `by' + _cons
			mat `trt'		= nullmat(`trt'), r(estimate)
			mat `trt_se'	= nullmat(`trt_se'), r(se)
			mat `trt_p'		= nullmat(`trt_p'), 2*min(ttail(e(df_r),r(estimate)/r(se)),1-ttail(e(df_r),r(estimate)/r(se)))
		qui tabstat `var', by(`by') stats(n) save
			mat `ctl_n' = nullmat(`ctl_n'), r(Stat1)
			mat `trt_n' = nullmat(`trt_n'), r(Stat2)
	}
	foreach mat in ctl ctl_se ctl_n ctl_p trt trt_se trt_p trt_n diff diff_se diff_p {
		mat coln ``mat'' = `varlist'
		eret mat `mat' = ``mat''
	}
end

// Program to display ttest results in a nice table
capt prog drop ttestTable2
program define ttestTable2
	args TABVARS BYVAR TABFILE TITLE LABEL HEAD1 HEAD2 HEAD3
	diffTest2 `TABVARS', by(`BYVAR')
	esttab using `TABFILE'.tex, title(`TITLE'\label{tab:`LABEL'}) nomtitles nonumbers collabels("`HEAD1'" "`HEAD2'" "`HEAD3'") varwidth(32) label replace booktabs width(0.9\hsize) cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)" `"N_1(fmt(a2) par("n=" "")) N_2(par("n=" ""))"') star(* 0.10 ** 0.05 *** 0.01) addnote("* p lt 0.10, ** p lt 0.05, *** p lt 0.01") noobs
end

// does not report obs
capt prog drop ttestTable2_noN
program define ttestTable2_noN
	args TABVARS BYVAR TABFILE TITLE LABEL HEAD1 HEAD2 HEAD3
	diffTest2 `TABVARS', by(`BYVAR')
	esttab using `TABFILE'.tex, title(`TITLE'\label{tab:`LABEL'}) nomtitles  nonumbers collabels("`HEAD1'" "`HEAD2'" "`HEAD3'") varwidth(32) label replace booktabs width(0.9\hsize) cells("mu_1(fmt(a2)) mu_2 d(star pvalue(d_p))" "sd_1(fmt(a2) par([ ])) sd_2(par([ ])) d_se(par)") star(* 0.10 ** 0.05 *** 0.01) addnote("* p lt 0.10, ** p lt 0.05, *** p lt 0.01") noobs
end

capt prog drop qregTable
program define qregTable
  args TABVARS XVAR TABFILE TITLE LABEL
  qregStats `TABVARS', by(`XVAR')
  esttab using `TABFILE'.tex,	///
	title(`TITLE'\label{tab:`LABEL'})	///
	 mtitles("Sample median (se)") nonumbers collabels("Treatment" "Control" "Difference")	///
	varwidth(32) label replace booktabs width(0.9\hsize)	///
	cells("trt(fmt(a2) star pvalue(trt_p)) ctl(star pvalue(ctl_p)) diff(star pvalue(diff_p))" ///
		  "trt_se(fmt(a2) par) ctl_se(par) diff_se(par)"	///
		 `"trt_n(fmt(a2) par("n=" "")) ctl_n(par("n=" ""))"')	///
	star(* 0.10 ** 0.05 *** 0.01)	///
	addnote("Standard errors in parentheses." "* p lt 0.10, ** p lt 0.05, *** p lt 0.01")	///
	noobs
end


// levenshtein distance

capture program drop lev
program define lev, rclass
	args word1 word2
	
	local L1 = length("`word1'")
	local L2 = length("`word2'")

	matrix A=J(`L2'+1, `L1'+1, 0)
	/* Create matrix of zero's */	

	forval i = 0 / `L1'			{
	/* Initialize first row */
		matrix A[1,`i'+1] = `i'		
	}

	forval j = 1 / `L2' 		{
	/* Initialize first column */
		matrix A[`j'+1,1] = `j'		
	}

	forval j = 1 / `L2'	{
	/* Loop through characters of word 2 */
		forval i = 1 / `L1' 	{
		/* Loop through characters of word 1 */

			if  substr("`word2'", `j', 1) == substr("`word1'", `i', 1) {
				local cost=0
			}							
			/*  Set cost=0 if there's a match; */
			else {
				local cost=1
			}					
			/*          cost=1 otherwise	*/
	
			local m = 1 + A[`j', `i'+1]
			/* Set current cell equal to min of:	*/
			local n = 1 + A[`j'+1, `i']		
			/*  cell directly above (m) + 1		*/
			local d = `cost' + A[`j', `i']
			/*  cell directly to left (n) + 1		*/
			matrix A[`j'+1,`i'+1]=min(`m',`n',`d')
			/*  cell diagonal above & left (d) + cost  */
		}
	}
	
	local lev = A[`L2'+1, `L1'+1]
	/* Grab the value from bottom, right cell */
	
	return local x = `lev'
	return local y = 3
	di "Levenshtein distance between `word1' and `word2' is `lev' "

end

capt prog drop labelsprogram
program labelsprogram, eclass
	
	cap label var tds_std "Total dissolved solids"
	cap label var tss_std "Total suspended solids"
	cap label var cod_std "Chemical oxygen demand"
	cap label var bod_std "Biochemical oxygen demand"
	cap label var an_std  "Ammonical nitrogen"
	cap label var spm_std "Suspended particulate matter"
	cap label var so2_std "Sulphur dioxide"
	cap label var nox_std "Nitrogen oxide"

end
	
// wide option takes number of joint-action categories, and checks
// all to update actionBig
cap program drop MakeCatBig
program def MakeCatBig	
	replace actionBig = 1 if action == 10
	replace actionBig = 2 if action == 31 | ///
		                 action == 33 | ///
				 action == 34 
	replace actionBig = 3 if action == 35 | ///
				 action == 51
	replace actionBig = 4 if action == 40
	//replace actionBig = 5 if action == 1
	replace actionBig = 6 if action == 61
	replace actionBig = 7 if action == 62 | ///
				 action == 63 | ///
				 action == 64 
end

/*
cap program drop MakeCatBig
program def MakeCatBig	
	syntax , [wide(numlist max=1)
	
	// define locals that have the correspondences between 
	// actionBig numbers and action numbrs
	local cb1 10
	local cb2 31 33 34
	local cb3 35 51
	local cb4 40
	
	local cb6 61
	local cb7 62 63 64
	
	
	if "`wide'" == "" {
		forv cb = 1(1)7 {
			foreach c of local cb`cb' }
				replace actionBig = `cb' if action == `c'
			}
		}		
	}
	else {
		forv j = 1(1)`wide'
		
		
	
	
end
*/

// diffTest3 
capt prog drop diffTest3
program diffTest3, eclass
  syntax varlist [fweight aweight pweight iweight] [if] [in], by(varname) [strata(varlist)] [ * ] 
  marksample touse
  markout `touse' `by'
  tempname N_1 N_2 sd_1 sd_2 mu_1 mu_2 d d_se d_t d_p
  foreach var of local varlist {
      qui ttest `var' if `touse', by(`by') `options'
      mat `N_1' = nullmat(`N_1'), r(N_1)
      mat `N_2' = nullmat(`N_2'), r(N_2)
      mat `mu_1' = nullmat(`mu_1'), r(mu_1)
      mat `mu_2' = nullmat(`mu_2'), r(mu_2)
      mat `sd_1' = nullmat(`sd_1'), r(sd_1)
      mat `sd_2' = nullmat(`sd_2'), r(sd_2)
	  
	  qui reg `var' `by' `strata' [`weight'`exp']
      mat `d'    = nullmat(`d'   ), _b[`by']
      mat `d_se' = nullmat(`d_se'), _se[`by']
      mat `d_t'  = nullmat(`d_t' ), (_b[`by']/_se[`by'])
      mat `d_p'  = nullmat(`d_p' ), (2*ttail( e(df_r), abs(_b[`by']/_se[`by'])))
  }
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p {
      mat coln ``mat'' = `varlist'
  }
  tempname b V
  mat `b' = `mu_1'*0
  mat `V' = `b''*`b'
  eret post `b' `V'
  eret local cmd "meanDiffTable"
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p {
      eret mat `mat' = ``mat''
  }
  tempname N1 N2 
  scalar `N1' = `N_1'[1,1]
  scalar `N2' = `N_2'[1,1]
  foreach sca in N1 N2 {
      eret sca `sca' = ``sca''
  }
  foreach mat in N_1 N_2 {
      eret mat `mat' = ``mat''
  } 
  
end
	
	
// diffTest4 (weights everything by user supplied weights)
capt prog drop diffTest4
program diffTest4, eclass
  syntax varlist [fweight aweight pweight iweight] [if] [in], by(varname) [strata(varlist)] [ * ] 
  marksample touse
  markout `touse' `by'
  tempname N_1 N_2 sd_1 sd_2 mu_1 mu_2 d d_se d_t d_p Stat1 Stat2
  foreach var of local varlist {
      //qui ttest `var' if `touse', by(`by') `options'
      tabstat `var' [`weight'`exp'] if `touse',by(`by') save statistics(N mean sd)
      mat `Stat1' = r(Stat1)
      mat `Stat2' = r(Stat2)
      
      mat `N_1' = nullmat(`N_1'), `Stat2'[1,1]
      mat `N_2' = nullmat(`N_2'), `Stat1'[1,1]
      mat `mu_1' = nullmat(`mu_1'), `Stat2'[2,1]
      mat `mu_2' = nullmat(`mu_2'), `Stat1'[2,1]
      mat `sd_1' = nullmat(`sd_1'), `Stat2'[3,1]
      mat `sd_2' = nullmat(`sd_2'), `Stat1'[3,1]
	  
	  qui reg `var' `by' `strata' [`weight'`exp']
      mat `d'    = nullmat(`d'   ), _b[`by']
      mat `d_se' = nullmat(`d_se'), _se[`by']
      mat `d_t'  = nullmat(`d_t' ), (_b[`by']/_se[`by'])
      mat `d_p'  = nullmat(`d_p' ), (2*ttail( e(df_r), abs(_b[`by']/_se[`by'])))
  }
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p {
      mat coln ``mat'' = `varlist'
  }
  tempname b V
  mat `b' = `mu_1'*0
  mat `V' = `b''*`b'
  eret post `b' `V'
  eret local cmd "meanDiffTable"
  foreach mat in mu_1 mu_2 sd_1 sd_2 d d_se d_t d_p {
      eret mat `mat' = ``mat''
  }
  tempname N1 N2 
  scalar `N1' = `N_1'[1,1]
  scalar `N2' = `N_2'[1,1]
  foreach sca in N1 N2 {
      eret sca `sca' = ``sca''
  }
  foreach mat in N_1 N_2 {
      eret mat `mat' = ``mat''
  } 
  
end	
	
/*******************************************************************************
Fuse two chains based on their actions and time lag.

This program takes as arguments the earlier chain ('before') and the later chain
('after'), as well as the maximum allowable lag between actions ('time') in
days. For any given action, the program checks up to thirty actions before for 
possible matches. This can be changed with the option 'checknum'. 

The option afterfirstonly ensures that the later action is the first in its
chain. This is used when inspections are added onto the front of chains 
lacking them. It requires the provision of a variable that has the maximum
action in each chain, so that only chains with only inspections are added
onto the front.
*******************************************************************************/
cap program drop ChainCombiner
program def ChainCombiner
	syntax , BEFore(numlist) AFTer(numlist) Time(numlist) [checknum(integer 30)] [samedatesort(varname)] [afterfirstonly(varname)]
	
	// set default (as used in eventsChainCombiner
	if "`samedatesort'" == "" local samedatesort n
	
	/* Create locals that contain OR statements to make chain linkages
	for each action code in the BEFORE and AFTER arguments.
        Make two sets of locals.
          1/ aftercat and beforecat1, used to identify the 'after' argument
             i.e., action[_n] == after action & action[_n-`j'] == before action.
          2/ aftercat and beforecat2, are used to refer to the 'before'
             argument in the same way.
         Check for actions to combine over a maximum of `checknum'
         (default = 30) adjacent actions. */
  
	forvalues j = 1(1)`checknum' {
	    
	    local aftercat1_`j' ""
	    local aftercat2_`j' ""
	    local beforecat1_`j' ""
	    local beforecat2_`j' ""			
	    
	    foreach number of local after {
	    	local aftercat1_`j' "| action[_n]==`number' `aftercat1_`j''"
	    	local aftercat2_`j' "| action[_n +`j']==`number' `aftercat2_`j''"	
	    }
	    foreach number of local before {
	    	local beforecat1_`j' "| action[_n - `j']==`number' `beforecat1_`j''"	
	    	local beforecat2_`j' "| action[_n]==`number' `beforecat2_`j''"
	    }	
	    
	    // remove leading "|" symbol from locals and encase in parentheses.
	    local aftercat1_`j' =  subinstr("`aftercat1_`j''","|","",1)
	    local aftercat2_`j' =  subinstr("`aftercat2_`j''","|","",1)
	    local beforecat1_`j' = subinstr("`beforecat1_`j''","|","",1)
	    local beforecat2_`j' = subinstr("`beforecat2_`j''","|","",1)
	    
	    local aftercat1_`j' "( `aftercat1_`j'' )"
	    local aftercat2_`j'  "( `aftercat2_`j'' )"	
	    local beforecat1_`j' "( `beforecat1_`j'' )"
	    local beforecat2_`j' "( `beforecat2_`j'' )"	
	    
	    /*
	    Make locals that control combinations if afterfirstonly
	    */
	    if "`afterfirstonly'" != "" {
	    	local chainpositioncontrol1_`j' "& withinchainid == 1"
	    	local chainpositioncontrol2_`j' "& withinchainid[_n+`j'] == 1"
	    	local allinspectionscontrol1_`j' "& `afterfirstonly'[_n-`j'] == 10"
	    	local allinspectionscontrol2_`j' "& `afterfirstonly' == 10"
	    }		
	}
	
	/***********************************************************************
	Look for all actions that match the qualifications set in the 
	locals, and are not already in the same chain. If, for a given firm,
        there are multiple action pairs that fit the qualifications, focus only
        on the earliest	pair.

	Once both of these actions are tagged (tag = 1), create a variable that
        refers to all observations in the chains that need to be linked
        (tagbig = 1). Then, each observation in the two chains is assigned the
        new chain id of the lower of the two existing chain ids.
	
	The program iterates until no new changes are being made. Since
        combining chains always reduces the mean chain id number, I use the
        mean chain number to control the iteration.
	***********************************************************************/
	local change = 1
	qui su chain 
	local lastround = r(mean)
	
	while `change' > 1e-12 {
	    qui {
	    	sort gpcbid chain date `samedatesort'
	    	by gpcbid chain: g withinchainid = _n
	    	g tag = .
	    	
	    	// tag the later action of the pair
	    	forvalues j = 1(1)`checknum' {
	    	    replace tag = 1 if gpcbid[_n] == gpcbid[_n-`j'] & ///
	    	    	        	   `aftercat1_`j''  & ///
	    	    	        	   `beforecat1_`j'' & ///
                                           (date[_n] - date[_n-`j'] <= `time') & ///
	    	    	                   (date[_n] - date[_n-`j'] >= 0) & ///
                   	    	           chain[_n] != chain[_n-`j'] `chainpositioncontrol1_`j'' `allinspectionscontrol1_`j''
	    	    	
	    	}
	    	
	    	// Ensure that only one pair of actions per gpcbid is tagged
	    	by gpcbid: g tagnum = _n if tag == 1		
	    	by gpcbid: egen tagnum_min = min(tagnum)
	    	replace tag = . if tagnum != tagnum_min
	    	
	    	// tag the earlier action that corresponds to the first action.
	    	forvalues j = 1(1)`checknum' {
	    		replace tag = 1 if gpcbid[_n] == gpcbid[_n+`j'] & /// 
	    				   `aftercat2_`j'' & ///
	    				   `beforecat2_`j''  & ///
	    				   (date[_n+`j'] - date[_n] <= `time') & ///
	    				   (date[_n+`j'] - date[_n] >= 0) & ///
	    				   chain[_n+`j'] != chain[_n] & ///
	    				   tag[_n+`j']==1 `chainpositioncontrol2_`j'' `allinspectionscontrol2_`j''
	    	}
	    	
	    	// for each chain that has been tagged as needing to be joined,
	    	// change the chain id to the lowest of the two existing ids.
	    	by gpcbid chain: egen tagbig = min(tag)
	    	bys gpcbid tagbig: egen chain2 = min(chain) if chain!=. & tagbig==1
	    	replace chain = chain2 if tagbig==1
	    	
	    	// update variable that has maximum action if necessary
                // (this is only used when adding on inspection-only chain
                //  to the front of chains that otherwise have no inspection)
	    	if "`afterfirstonly'" != "" {
	    	    drop `afterfirstonly'
	    	    bys gpcbid chain: egen `afterfirstonly' = max(action)
	    	}
	    	drop tag* chain2 withinchainid
	    
	    	// control iteration
	    	su chain
	    	local change = `lastround' - r(mean) 
	    	local lastround = r(mean)
	    }
	}
end
/* ChainCombiner */


// after gmm regression, makes output nice for esttabing, and hits estto. can use like gmm .... , next line: TurnToCoefs, title(xxxx), and so on.	
cap prog drop TurnToCoefs
prog def TurnToCoefs, eclass
	syntax , [title(string)]
	tempname newb newV
	
	// input b and V, with V as vector (all we care about ar diag elements)
	mat `newb' = e(b)
	mat `newV' = vecdiag(e(V))
	
	local N = e(N)
	// get rid of eq labels
	foreach matrix in newb newV {
		local matnames : coleq ``matrix''
		matrix colnames ``matrix'' = :
		matrix colnames ``matrix'' = `matnames'
	}	
	
	// turn V back into a matrix	
	matrix `newV' = diag(`newV')
	
	//eret repost b = `newb' V = `newV'
	eret post `newb' `newV', obs(`N')
	eststo, title(`title')
end

/* diffTestBootstrap */
// Used for Paper Table 8
cap prog drop diffTestBootstrap /* drops any program with same name */ 
program diffTestBootstrap, eclass  /* defines the program name and class */
	syntax varlist, by(varname) c(int) t(int) /* defines the program syntax */
	tempname sd_1 sd_2 d_se d_p /* */
	foreach VAR of local varlist {
		count
		assert r(N) == 2
		
		su `VAR' if ins_treatment == 0
		local `VAR'_c_m = r(mean)
		
		su `VAR' if ins_treatment == 1
		local `VAR'_t_m = r(mean)
			
		ttesti `c' ``VAR'_c_m' ${`VAR'_c_sd} `t' ``VAR'_t_m' ${`VAR'_t_sd}, unequal

		mat `sd_1' = nullmat(`sd_1'), r(sd_2)
		mat `sd_2' = nullmat(`sd_2'), r(sd_1)
		mat `d_se' = nullmat(`d_se'), r(se)
		mat `d_p'  = nullmat(`d_p' ), r(p)
	}

	foreach mat in sd_1 sd_2 d_se d_p {
		mat coln ``mat'' = `varlist'
	}
	foreach mat in sd_1 sd_2 d_se d_p {
		eret mat `mat' = ``mat''
	}
end

// bootstrapRatios
    //   Calculating total costs, inspections and ratios on each iteration
    // Define a program to calculate the ratio of the means of cost to
    //   the mean of the number of inspections, so that this can be
    //   bootstrapped and the SD of the ratio can be calculated

	cap program drop bootstrapRatios
   cap program define bootstrapRatios
    	args VAR TREAT
    	preserve
    	    collapse (sum) `VAR' (sum) number_inspections, by(ins_treatment)
    	    count
    	    assert r(N)==2
    	    
    	    g `VAR'_per_insp = `VAR' / number_inspections
    	    keep if ins_treatment == `TREAT'
    	    keep `VAR'_per_insp
    	    su `VAR'_per_insp
    	restore
    end


