//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//   Settings and paths

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Automated path selection
cd "../.."
local CWD `c(pwd)'
local ROOT "`CWD'"

cd "`ROOT'/code/01_reduced_form"
display "ROOT directory: `ROOT'"

// Data analysis and exhibits
local WORK              "`ROOT'/data/01_reduced_form"
local RAW               "`ROOT'/data/01_reduced_form/raw"
local CLEAN             "`ROOT'/data/01_reduced_form/clean"

local PAPERFIGURES 	"`ROOT'/output/figures"
local PAPERTABLES	"`ROOT'/output/tables"

local MASTER 		"`ROOT'/data/cleaned/assignment"
local ANNUAL 		"`ROOT'/data/cleaned/audit_miscdata"
local AUDITS 		"`ROOT'/data/cleaned/audits_seasonal"
local BACKCHECKS 	"`ROOT'/data/cleaned/backchecks"
local GPCB 		"`ROOT'/data/cleaned/interaction_regulator"
local INDUSTRY 		"`ROOT'/data/cleaned/interaction_plants"
local ENDLINE		"`ROOT'/data/cleaned/endline"
local XGN		"`ROOT'/data/cleaned/XGN"
local MATLAB		"`ROOT'/data/cleaned/matlab"
local CCATREAT		"`ROOT'/data/cleaned/CCA_treatment"
local ROSTER 		"`ROOT'/data/cleaned/industry_roster_2009"
local PREPPED		"`ROOT'/data/exhibitData"
local TEMP 		"`ROOT'/data/temp"
local OUTPUT 		"`ROOT'/exhibits/graphs/gph_files"
local GPHOUT 		"`ROOT'/exhibits/graphs"
local TABOUT 		"`ROOT'/exhibits/tables"
local GRAPHCODE		"`ROOT'/code/graphs"
local TABCODE		"`ROOT'/code/tables"
local PREPCODE		"`ROOT'/code/cleaning"

// Paper and paper exhibits
local PAPER 		"`DROPBOX'/inspectionPaper"
local APPTABLES 	"`ROOT'/exhibits/OnlineAppendixDone"

// Data from audits project
local HETEROPREPPED     "`DROPBOX'/auditorDataAnalysis/data/exhibitData"
local HETEROENDLINE     "`DROPBOX'/auditorDataAnalysis/data/cleaned/endline"


*ssc install listtab

// List action numbers
local actionnums 10 21 22 23 24 25 31 33 34 35 39 40 51 61 62 63 64 69
local actionnums98 "`actionnums 98'"

// List parameters we care about when pooling
local allparams			tds tss cod bod an spm so2 nox
local allparams_star
local allparams_std

foreach var of local allparams {
	local allparams_star "`allparams_star' `var'*"
	local allparams_std  "`allparams_std' `var'_std"
}

// List parameters for which to make individual graphs
local selectparams		tds cod bod spm so2 nox

// List water parameters to include in raw placebo table
local waterparams 		tds cod bod an tss
local airparams	 		spm so2 nox

local groupparams		air water

// List ETP types
local etplist aer fil cdt cla cet mlt fip flm flo inc las neu ogt set sdb sht 

local etplab_aer "Aeration Tank"
//local etplab_cfl "Carbon Filter"
local etplab_fil "Carbon/Sand Filter"
local etplab_cdt "Chemical Dosing Tank"
local etplab_cla "Clarifier"
local etplab_cet "Collection/Equalization Tank"
local etplab_fip "Filter Press"
local etplab_flm "Flash Mixer"
local etplab_flo "Floculator"
local etplab_inc "Incinerator"
local etplab_las "Lamella Settler"
local etplab_mlt "Effect Evaporator"
local etplab_neu "Neutralizer"
local etplab_ogt "Oil and grease trap"
//local etplab_saf "Sand Filter"
local etplab_sdb "Sludge Dry Beds"
local etplab_set "Settling Tank"
local etplab_sht "Sludge Holding Tank"

local apcmlist bgf cyc dus esp scr

local apcmlab_scr "Scrubber"
local apcmlab_cyc "Cyclone"
local apcmlab_bgf "Bag filter"
local apcmlab_dus "Dust collector"
local apcmlab_esp "Electrostatic Precipatator"

local apcmetplist "`etplist' `apcmlist'"

// locals for what equipment types effect what pollutants

local tds_effect_list         fil cla cet fip flm flo     las         sdb set sht
local cod_effect_list aer cdt fil cla     fip flm flo     las     neu
local bod_effect_list aer cdt fil cla     fip flm flo     las     neu
local  an_effect_list aer     fil cla cet     flm flo             neu
local tss_effect_list         fil cla cet fip flm flo     las         sdb set sht
// should an have fip?
// incinerator is nowhere
// could not figure out effect evaporator

local spm_effect_list bgf cyc dus     scr
local so2_effect_list bgf         esp scr 
local nox_effect_list bgf         esp scr 
// there is a diff between wet and dry scrubbers. wet seems to focus on spm. might be worthwhile to
// split them up.

local fuel_type_list cons_agrowaste cons_coal cons_coke cons_diesel cons_natgas cons_furnaceoil cons_lignite cons_solidfuel cons_wood

local CompactChainNum 12

//	Universal graph formatting
local gcolor1 "navy"
local gcolor2 "cranberry"
local gcolor3 "midblue"
local gcolor4 "ltblue"
local gcolor5 `""96 160 255""'	// (in between midblue and ltblue)
local gcolor6 "maroon"
local gcolor7 "gs7"
local gtitlesize "large"
local glabelsize "medlarge"
local glabelsizealt "medium"
local gproportions "ysize(8) xsize(10)"
local gproportions_plus "ysize(8.7) xsize(10)"
local gproportions_tall "ysize(15) xsize(14)"
local gproportions_tall_plus "ysize(16) xsize(13)"
local gproportions_xtall "ysize(15) xsize(10)"
local gproportions_xtallplus "ysize(16) xsize(10)"
local gbysubtitleoptions "subtitle(, bcolor(gs13))"

//	For policy or academic audience?
local policy 0
if `policy'==1 local aud_treatment_name	"Modified audit"
if `policy'==1 local aud_control_name	"Standard audit"
if `policy'==0 local aud_treatment_name	"Audit treatment"
if `policy'==0 local aud_control_name	"Audit control"

//	Use a graph style scheme that sets background color to white. This eliminates the 1-pixel vertical
//		gray line on the right edge of graphs produced using -graph combine-.
cap set scheme s2color_bgwhite


// note that the 'ignore' variables are added in at the end, after chains aredefined.
cap label drop actionLabels
label define actionLabels	///
	10	"Inspection report"	///
	21	"CCA: Amendment"	///
	22	"CCA: Approval"	///
	23	"CCA: Further details required"	///
	24	"CCA: Rejection"	///
	25	"CCA: Other"	///
	31	"Action: Letter"	///
	33	"Action: Show Cause Notice"	///
	34	"Action: Closure Notice"	///
	35	"Action: Closure Direction"	///
	39  "Action: Ignore" ///
	40	"Revocation of Closure Direction"	///
	50	"Monitoring direction"	///
	51	"Third-party response"	///
	60	"Industry response"	///
	61	"Industry: Contestation"	///
	62	"Industry: Equipment installed"	///
	63	"Industry: Process installed"	///
	64	"Industry: Bank guarantee posted"	///
	69	"Industry: Ignore" ///
	98	"Other"

cap label drop inspectionorigin
label def inspectionorigin ///
	1 "XGN Parsed" ///
	2 "Entered" ///
	3 "Audits dataset"

label def actionBig ///
	0 "Null" ///
	1 "Inspect" ///
	2 "Warn" ///
	3 "Punish" ///
	4 "Accept" ///
	5 "Firm: Ignore" ///
	6 "Firm: Protest" ///
	7 "Firm: Comply" ///
	,modify
/*
label def actionBigjLabel ///
	1 "Firm: Ignore" ///
	2 "Firm: Protest" ///
	3 "Firm: Comply" ///
	4 "Inspect" ///
	5 "Accept" ///
	6 "Warn" ///
	7 "Punish" ///
	8 "Inspect-Accept" ///
	9 "Inspect-Warn" ///
	10 "Inspect-Punish"

	
