function [ b, se ] = estimCcpPlant( a, s, omit )
% estimCcpPlant Estimate conditional choice probabilities of action given
%   the state variable.
% 
% INPUT:
%   a - N X 3 matrix of actions, where N is the number of turns at which
%       the plant can move and the 3 columns are dummies for possible
%       actions.
%   s - state matrix at turns where plant moves.
%   omit - indices for columns of state space to omit from estimation.
%
% OUTPUT:
%   b  - matrix of coefficients for multinomial logit
%   se - standard errors for the coefficients

% Create design matrix, with no interactions to start (not saturated)
%   Could do this ex ante for speed if repeating much.
i = 1:size(s,2);
i = i( ~ismember(i,omit) );
X = s( :, i );

% Fit multinomial logit model
%   It is faster to aggregate the data first by unique rows of the design
%   matrix and then fit the model.
%   [ b, ~, S ] = mnrfit(X,Y);
[ UX, ~, J ] = unique(X,'rows');
% UY           = [accumarray(J,a==1) accumarray(J,a==2) accumarray(J,a==3)];
UY           = [accumarray(J,a==1) accumarray(J,a==2)];
[ b, ~, S ]  = mnrfit(double(UX),double(UY));
se = S.se;

end

