function [ beta ] = estimateBeta( ids, date, plantMove, r)
% estimateBeta Estimate discount factor using time spacing between rounds
%   ids  - chain, plant, chain within plant numeric ids
%   date - date of chain action being taken
%   plantMove - turns at which the plant moves
%   r    - annual return on capital

samechain = [ ids(1:end-1,1) == ids(2:end,1); false ];
deltadate = date([false; samechain(1:end-1)]) - date([samechain]);
tperiod   = mean(deltadate);

rp   = exp( tperiod/365 * log(1+r) ) - 1;
beta = 1 / ( 1 + rp );

end

