function [ si, sif ] = genFutureState( s, S, ids )
% genStateIndex Return index i for each state in data
% 
% INPUT:
%   S   - |aP| X |aR| X |pol| matrix of all possible states, in 2-D
%   s   - N X |s| matrix of states in data
%   ids - id numbers for chain, plant, chain within plant
%
% OUTPUT:
%   si   - N X 1 vector of state indices, giving the row of S to which 
%          the current round of s belongs.
%   sif  - N X 1 vector of state indices, giving the row of S to which 
%          the next round of s belongs, or 0 if the chain terminates.

sif          = zeros(size(s,1),1);
continuingi  = [ ids(1:end-1,1) == ids(2:end,1); false ];
continuingif = [ false; continuingi(1:end,:) ];

[ ~, si ] = ismember(s,S,'rows');
sif( continuingi ) = si( continuingif );

end
