function [ Phat3 ] = predCcpRegul( b, S, omit, timeDim )
% estimCcpRegul Estimate conditional choice probabilities of action given
%   the state variable.
% 
% INPUT:
%   b       - matrix of coefficients for multinomial logit
%   omit    - indices for columns of state space to omit from estimation.
%   S       - states at which to evaluate the predicted probabilities
%   timeDim - Number of time dummies, e.g. t>0, t>3, etc., comprising
%             time dimension of state.
%
% OUTPUT:
%   Phat  - (|S|+|sRt|) X K matrix of predicted probabilities for each 
%           action choice.
%   Phat3 - Phat reshaped to |S| X K X |sRt| to keep time dimension of 
%           state distinct.

% Create design matrix
i = 1:size(S,2);
i = i( ~ismember(i,omit) );
X = S( :, i );

Phat  = mnrval( b, X );
Phat3 = zeros(size(Phat,1)/timeDim,size(Phat,2),timeDim);
for i = 1:timeDim
    Phat3(:,:,i) = Phat(i:timeDim:end,:);
end

end