function [ ] = tabCcp( file, title, colHeads, b, se, ...
                       stateNames, omit )
% Print table of data in a nicely-formatted manner
%   file : file to which to write table contents
%   title : string with table heading
%   colHeads : cell array of column headings for variables
%   rowHeads : cell array of row headings, often group or id variables
%   b        : coefficient estimates
%   se       : standard errors for coefficients
%   format : string of format specifications

% Check format string and apply default
columns = size(b,2);
format  = ['%15s ',repmat('%8.2f ',1,columns)];

if file ~= 1
    fid = fopen(file,'w');
    fprintf('\nWriting file %s to disk . . ',file);
else
    fid = file;
end

% Title of table
if ~iscell( title )
    fprintf(fid,'\n%40s\n',title);
else
    fprintf(fid,'\n');
    for t = 1:length(title)
        fprintf(fid,'%40s\n',title{t});
    end
end

% Column headings
cformat = regexp(regexprep(format,'\.\df','s'),' ','split')';
fprintf(fid,cformat{1},'');
for c = 1:columns
    fprintf(fid,cformat{c+1},colHeads{c});
    if c < columns
        fprintf(fid,' ');
    else
        fprintf(fid,'\n');
    end
end

% Variable labels
i = 1:length(stateNames);
i = i( ~ismember(i,omit) );
stateNames = stateNames(i);
stateNames{end+1} = 'Constant';

% Flip constant to bottom for display
b  = [ b(2:end,:)  ; b(1,:)  ];
se = [ se(2:end,:) ; se(1,:) ];

% Data rows
for r = 1:size(b,1)
    rowHead = stateNames{r};
    fprintf(fid,[format,'\n'],rowHead,b(r,:));
    fprintf(fid,[format,'\n'],'',se(r,:));
end

if file ~= 1
    fprintf('complete.\n');
    fclose(fid);
end

end


