function [ ] = tabDisplay( fid, title, colHeads, rowHeads, data, format )
% Print table of data in a nicely-formatted manner
%   fid : file id to which to write table contents
%   title : string with table heading
%   colHeads : cell array of column headings for variables
%   rowHeads : cell array of row headings, often group or id variables
%   data : data array
%   format : string of format specifications

% Check format string and apply default
if isempty( format )
    format = ['%15s ',repmat('%10.2f ',1,size(data,2))];
end

% Title of table
if ~iscell( title )
    fprintf(fid,'\n%40s\n',title);
else
    fprintf(fid,'\n');
    for t = 1:length(title)
        fprintf(fid,'%40s\n',title{t});
    end
end

% Column headings
cformat = regexp(regexprep(format,'\.\df','s'),'\\t','split')';
cformat = regexp(cformat{1},'\s','split');
columns = length(cformat) - 1;
for c = 1:columns
    fprintf(fid,cformat{c},colHeads{c});
    if c < columns
        fprintf(fid,'\t');
    else
        fprintf(fid,'\n');
    end
end

% Data rows
for r = 1:size(data,1)
    if iscell( rowHeads )
        rowHead = rowHeads{r};
    else
        rowHead = rowHeads(r);
    end
    
    if iscell( data ) 
        fprintf(fid,[format,'\n'],rowHead,data{r,:});
    else
        fprintf(fid,[format,'\n'],rowHead,data(r,:));
    end
end

end

