function [ ] = tabLatex( fid, title, colHeads, rowHeads, data, format )
% Print table of data in a nicely-formatted manner
%   file      : file to which to write table contents
%   title    : string with table heading
%   colHeads : cell array of column headings for variables
%   rowHeads : cell array of row headings, often group or id variables
%   data     : data array
%   format   : string of format specifications, separated by tabs

% Adjust format with latex separators
if isempty( format )
    format = ['%15s',repmat('\t%10.2f',1,size(data,2))];
end
format = regexprep(format,'\\t','&');

% Create single title string if cell input
if iscell( title )
    oldtitle = title;
    title    = '';
    for t = 1:length(oldtitle)
        title = [ title, oldtitle{t} ];
        if t < length(oldtitle)
            title = [ title, '\\\\' ];
        end
    end
end

% Front matter
columns = size(data,2);
fprintf(fid,'\\begin{table}[!ht]\n\t\\centering\n\t');
fprintf(fid,'\t\\caption{%s}\n',title);
fprintf(fid,'\\begin{tabular}{%s}\n',['l',repmat('r',1,columns)]);

% Title of table
fprintf(fid,'\t\t\\toprule\n');

% Column headings
cformat = regexp(regexprep(format,'\.\df','s'),'&','split')';
% columns = length(cformat);
for c = 1:columns+1
    fprintf(fid,cformat{c},colHeads{c});
    if c <= columns
        fprintf(fid,'&');
    else
        fprintf(fid,'\\\\\n');
    end
end
fprintf(fid,'\t\t\\midrule\n');

% Data rows with row headings
for r = 1:size(data,1)
    if iscell( data )
        fprintf(fid,['\t\t',format,'\\\\\n'],rowHeads{r},data{r,:});
    else
        fprintf(fid,['\t\t',format,'\\\\\n'],rowHeads{r},data(r,:));
    end
end

% End matter
fprintf(fid,'\t\t\\bottomrule\n');
fprintf(fid,'\t\\end{tabular}\n');
fprintf(fid,'\\end{table}\n');
 
end               
                