function [ sigma, Vhat ] = covarianceTargetingMoments( gmm, ...
                                                   thetaHat, del, signs )
%covarianceTargetingMoments Calculate covariance matrix of targeting
%   moments.
%
% INPUT: 
%  gmmTheta - Objective function
%  thetaHat - Parameter estimates at which to calculate objective 
%  del      - Finite difference in parameters to use in calculating
%             gradient.
%  signs    - vector of indicators -1, 0, 1 for whether parameters have
%             been log-transformed in estimation to preserve sign.
%
% OUTPUT:
%  Omega    - Covariance matrix of parameter estimates

[ ~, ~, OmegaHat, N ] = gmm( thetaHat );

m = size(OmegaHat,1);
p = length(thetaHat);

signs = signs(1:p);
gpT   = exp(abs(signs).*thetaHat);

dGdT = zeros(m,p);
for j = 1:p
        
    delj    = zeros(size(thetaHat));
    delj(j) = del;

    [ ~, gp, ~, ~ ] = gmm( thetaHat + delj );    
    [ ~, gm, ~, ~ ] = gmm( thetaHat - delj );

    dGdT(:,j) = (gp - gm)./(2*del);
        
end

Vhat  = inv( dGdT' * inv(OmegaHat) * dGdT ) ./ N;
sigma = sqrt(diag(Vhat)) .* gpT;

end

