function [ sigma, Vhat ] = covarianceTargetingMomentsCon( gmm, ...
                                                   thetaHat, del, signs, ...
                                                   nlcon )
%covarianceTargetingMoments Calculate covariance matrix of targeting
%   moments.
%
% INPUT: 
%  gmmTheta - Objective function
%  thetaHat - Parameter estimates at which to calculate objective 
%  del      - Finite difference in parameters to use in calculating
%             gradient.
%  signs    - vector of indicators -1, 0, 1 for whether parameters have
%             been log-transformed in estimation to preserve sign.
%
% OUTPUT:
%  Omega    - Covariance matrix of parameter estimates

[ ~, ~, OmegaHat, N ] = gmm( thetaHat );

m = size(OmegaHat,1);
p = length(thetaHat);

signs = signs(1:p);
gpT   = exp(abs(signs).*thetaHat);

G = zeros(m,p);
A = zeros(2,p);   
for j = 1:p
        
    delj    = zeros(size(thetaHat));
    delj(j) = del;

    % Gradient of objective 
    [ ~, gp, ~, ~ ] = gmm( thetaHat + delj );    
    [ ~, gm, ~, ~ ] = gmm( thetaHat - delj );
    G(:,j) = (gp - gm)./(2*del);
    
    % Gradient of constraint
    [ ~, ap ] = nlcon( thetaHat + delj );
    [ ~, a  ] = nlcon( thetaHat );
    A(:,j) = (ap - a)./del;
        
end

B     = G' * inv(OmegaHat) * G;

% Unconstrained
% VhatUnc  = inv( B ) ./ N;
% sigmaUnc = sqrt(diag(VhatUnc)) .* gpT;

% Constrained
M     = eye(p) - B^-0.5*A'*inv(A*inv(B)*A')*A*B^-0.5;
Vhat  = B^-0.5 * M * B^-0.5 ./ N;
sigma = sqrt(diag(Vhat)) .* gpT;

end

