function [ EI, EI2, e2XI, e2XI2 ] = expectedInspectionsP( lambda, beta, sig1, rho, ...
                                             XT, XTwt )
%abateBudget Calculate inspections for each plant 
%   
% INPUTS:
%   lambda - Parameters of targeting function theta_t =
%            {beta_0,beta_3}.
%   beta   - {beta_1,beta_2} additional coefficients on observables in
%            argument of inspection targeting function.
%   These inputs define step-like function for inspection
%       targeting rule. Given these parameters, the inspections given to
%       any plant as a function of its pollution shock u_1 are :
%         I(u_1;x) = beta_3 * Phi( beta_0 + beta_1*X + beta_2*T + u_1 / 
%                                  rho*sig1 ) 
%
% Plant observables:
%   XT   - Plant-level covariates and treatment assignment, by type
%   XTwt - Weights for plant types, in the same order as XT
%
% Parameters
%   sig1 - standard deviation of observable pollution shock
%   rho  - targeting error parameter, as a fraction of sig1
%
% OUTPUT:
%   EI  - Expected inspections for plants with each XT
%   EI2 - Expected inspections squared

% aj = -(lambda(1) + XT*beta)/sig1;
aj = -(lambda(1) + XT*beta);

% Expected inspections, given observables
% EI = lambda(2) * normcdf(-aj/(rho^2+1)^0.5);
EI = lambda(2) * normcdf(-aj/(rho^2+sig1^2)^0.5);
  
% Expected inspections squared
% EI2 = lambda(2)^2 * mvncdf(-[aj aj],[ 0 0 ],[ 1+rho^2 1; 1 1+rho^2 ]);
EI2 = lambda(2)^2 * mvncdf(-[aj aj],[ 0 0 ],...
      [ rho^2+sig1^2 sig1^2; sig1^2 rho^2+sig1^2 ]);

% Expected product of inspections and pollution error
% e2XI = lambda(2) * sig1/rho * normpdf( aj / (1+rho^2)^0.5 );
e2XI = lambda(2) * sig1^2/rho * normpdf( aj / (rho^2+sig1^2)^0.5 );

% Expected product of inspections squared and pollution error
% e2XI2 = 2*lambda(2)^2 * sig1/rho * normpdf( aj ./ (1+rho^2)^0.5 ) .* ...
%         normcdf( -aj ./ (((1+rho^2)/rho)^2+1) );
e2XI2 = 2*lambda(2)^2 * sig1^2/rho * normpdf( aj ./ (rho^2+sig1^2)^0.5 ) .* ...
        normcdf( -aj*rho ./ (sig1^2+sig1*rho+rho^2) );
    
end

