function [ lnPsHat, IHat ] = generateRunDataLatent( X, T, phi, beta, S )
%simulateRunDataLatent Predict values of latent pollution and latent
%  inspections given parameters.
%
% INPUTS:
%   X    - Design matrix, including constant
%   T    - Treatment assignment
%   phi  - Pollution equation coefficients on [constant X Run] 
%   beta - Inspection equation coefficients on [constant X]
%   S    - Number of simulations for which to replicate mean values
%
% OUTPUTS:
%   lnPsHat - Predicted value of latent log pollution
%   IHat    - Predicted value of latent inspections

% Latent pollution
lnPsHat = repmat( X * phi(1:end-1), [1 S]);

% Latent inspections (exclude constant from X)
IHat    = repmat( [X(:,2:end) T] * beta, [1 S]);

end
