function [ lambda ] = inspectionTargetingFOCInit( theta, uI, Nbar, rho, ...
                                                  sigc, XT, XTwt, AbsV, ...
                                                  signs, lengths )
%inspectionTargetingOptimal  Calculate whether lambda parameters meet
%   the constraint of solving the regulator's targeting problem.
%
% INPUTS:
%   theta - Parameter values for:
%             Inspection equation beta = {beta_X beta_T}
%             Pollution equation phi = {phi0 phi1 phi2}
%             Error parameters: kc log(sigmac) sigma1 sigma2
%             Targeting parameters: lambda_0, lambda_1
%             Lagrange multiplier: gamma
%   uI    - 127 x 2 matrix of N(0,1) errors at which to evaluate
%           regulator's objective function on each iteration
%   Nbar    - predicted latent level of inspections
%   AbsV    - penalty function
%
% OUTPUTS:
%   ceq  - difference between targeting parameters {lambda0,lambda1}
%          and the optimal targeting parameters (lambda0*,lambda1*)

% Solve for optimal targeting rule given budget constraint and parameters
focs = @(x) inspectionTargetingFOClam( x, theta, rho, sigc, uI, ...
                                       Nbar, XT, XTwt, AbsV, ...
                                       signs, lengths );
                           
foptions = optimset('Display','iter','LargeScale','off',...
                     'TolFun',1e-15,'TolX',1e-15,'TolCon',1e-2,...
                     'MaxIter',1e4,'MaxFunEvals',1e5);

lambda0 = theta(end-1:end);
% LB    = [ -Inf;   0;  0  ];
% UB    = [  Inf; Inf; Inf ];
% lamgam = fmincon(focs,lamgam0,[],[],[],[],LB,UB,[],foptions); 

lambda  = fminsearch( focs, lambda0, foptions );

end

