function [ beta, stderr ] = ivregress(Y,X,Z)
%ivregress Run two-stage least-squares
%   
% INPUTS:
%   Y - dependent variable
%   X - regressors including endogenous variable
%   Z - instruments including regressors w/o endogenous variable
%
% OUTPUTS:
%   beta - vector of coefficients
%   stderr - standard errors

  % Degrees of freedom
  n = length(Y);
  k = size(X,2); 
  df = n - k; 

  % First stage and second stage
  PZX  = Z*inv(Z'*Z)*Z'*X;
  beta = inv(PZX'*PZX)*PZX'*Y;

  % Structural residuals
  ehat = Y - X*beta;

  % Asymptotic covariance
  s_hat   = ehat'*ehat/df; 
  var_hat = s_hat * inv(PZX'*PZX); 
  stderr  = sqrt(diag(var_hat)); 

  % Tests for significance
  t_stat  = beta ./ stderr; 
  pval    = betainc(df./(df+(1.*t_stat.^2)),(df./2),(1./2)); 
  
end