function [ ] = plotDiscretionValue( file, Nbar, prob, objective, ylimits )
% plotInspectionTargeting  Plot relationship of inspection targeting to 
%   unobservd pollution error.
% file      : filename in which to print or 1 to indicate print to screen
% Nbar      : inspection budget constraint
% prob      : vector of inspections
    
%% Formatting options
textProp = {'fontsize'    , 18, ...
            'FontName'    , 'Arial'};
labProp  = {'fontsize'    , 14, ...
            'FontName'    , textProp{4}};
        
% set(gca,'LineStyleOrder',{'-','--'});
% set(gca, 'ColorOrder',[0 0 1; 1 0 0]);
% hold on;
        
%% Main data plot
hold on;

plot(Nbar,prob(:,1),'b-.','LineWidth',1.15);
plot(Nbar,prob(:,2),'r-', 'LineWidth',1.15);
plot(Nbar,prob(:,3),'r:', 'LineWidth',1.15);
plot(Nbar,prob(:,4),'k--','LineWidth',1.15);

% Figure formatting
set(gcf, 'Color'         , 'w' );
set(gca, textProp{:}     , ...
         'Box'           , 'off', ...
         'LineStyleOrder', {':'} );
     
%         'YTick'         , [0:0.05:0.35], ...
%         'YTickLabel'    , {'0',' ','0.1',' ','0.2',' ','0.3',' '} );

% Axis labels
ylim(ylimits);
xlabel('Number of inspections per plant',textProp{:})
if objective == 1
    ylabtext = 'Probability of plant abatement';
elseif objective == 2
    ylabtext = 'Probability of plant compliance';
elseif objective == 3
    ylabtext = 'Average reduction in pollution';
end;   
ylabel(ylabtext,textProp{:})   


% Shape of figure and space occupied by data
set(gcf,'position',[20,20,600,600]);
set(gca,'position',[.15,.30,.8,.65]);

% Add legend
h = get(gca,'Children');
AX = legend(h([1 3 2 4]), {'Discretion: Full information',...
                           'Discretion: Partial information',...
                           'Treatment: Partial information, plus random inspections',...
                           'Uniform'},...
           'Position',[0.25, 0.05, 0.5, 0.11],textProp{:});
legend boxoff;

% plotTickLatex2D('XLabelDy',.02,'YLabelDx',.01);

% Vertical lines
controlx = 1.47;
treatx   = 2.93;
delta    = -0.05;
yl       = ylim;

line([controlx controlx],[0 yl(2)]);
text(controlx+delta,yl(2) - 0.01,'Control mean',labProp{:},'HorizontalAlignment','right');

line([treatx treatx],[0 yl(2)]);
text(treatx+delta,yl(2) - 0.01,'Treatment mean',labProp{:},'HorizontalAlignment','right');

hold off;

%% Export figure to file
if ischar( file )
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end