function [ ] = plotInspectionDist( file, I, T, Treatment )
% plotInspectionDist  Plot histogram of annual inspections
% file      : filename in which to print or 1 to indicate print to screen
% I         : number of inspections per year
% T         : treatment status
% Treatment : String 'Treatment' or 'Control' to indicate which
%               distribution to plot.
    
%% Formatting options
textProp = {'fontsize'    , 18, ...
            'FontName'    , 'Arial'};
labProp  = {'fontsize'    , 14, ...
            'FontName'    , textProp{4}};
        
%% Change data
if strcmp(Treatment,'Treatment')
    I = I(T);
else
    I = I(~T);
end

icounts = histc(I,[0:1:10]);
ifreq   = icounts(1:end-1) / length(I);

%% Main data plot: unconditional cost draws
%hist(I,[0.5:1:9.5]);
bar([0.5:1:9.5],ifreq,'b','BarWidth',1);
hold on;

% Figure formatting
xlim([0 10]);
%ylim([0 150]);
ylim([0 0.5]);
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off');

% Axis labels
xlabel(sprintf('Inspections in %s Plants',Treatment),textProp{:})
ylabel('Share of Plants',textProp{:})   

hold off;

%% Export figure to file
if ischar( file )
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end