function [ ] = plotInspectionTargeting( file, Is, sig1, xlimits, ylimits, ...
                                        smooth, spec )
% plotInspectionTargeting  Plot relationship of inspection targeting to 
%   unobservd pollution error.
% file      : filename in which to print or 1 to indicate print to screen
% p         : vector of pollution values
% n         : vector of inspections
% Is        : pollution targeting function handle, giving number of
%             inspections per year as a function of observable pollution
%             shock.
% sig1      : standard deviation of observable pollution shock
% xlimits   : range of x values
% ylimits   : range of y values
% smooth    : whether targeting function is a smooth function
% spec      : line specifications for targeting function
    
%% Formatting options
textProp = {'fontsize'    , 18, ...
            'FontName'    , 'Arial'};
labProp  = {'fontsize'    , 14, ...
            'FontName'    , textProp{4}};
                 
%% Targeting function to plot
if nargin < 6
    smooth = 0;
end

% Is  = targetStepFun(n);
% Is  = @(u) n(1)*normcdf(u,n(2),n(3));
% n   = Is(p);
        
%% Main data plot

% If there are discrete points to plot
% hseries = scatter(p,n);
% hold on;

if smooth
    x   = [xlimits(1):((xlimits(2)-xlimits(1))/1000):xlimits(2)];
    % Is  = pchip(p,n);
    % Is  = csapi(p,n);
    % Isu = ppval(Is,x);
    
    % Is  = polyfit(p,n,5);
    % Isu = polyval(Is,x);
    
%     Is = @(xi) interp1(p,n,xi,'linear','extrap');
    
    Isu = Is(sig1*x);    
    plot(x,Isu,spec,'LineWidth',1.15);
end

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off');
     
% Axis labels
xlim(xlimits);
ylim(ylimits);
xlabel('Observed component of pollution',textProp{:})
ylabel('Number of inspections',textProp{:})   

% Shape of figure and space occupied by data
set(gcf,'position',[20,20,600,600]);
set(gca,'position',[.15,.30,.8,.65]);

% Add legend
if strcmp(spec,'r:')
    h = get(gca,'Children');
    AX = legend(h([1 2 3]), {'Optimal targeting function: full information',...
                             'Optimal targeting function: present information',...
                             'Unconstrained targeting function'},...
               'Position',[0.25, 0.05, 0.5, 0.11],textProp{:});
    legend boxoff;
end

hold off;

%% Export figure to file
if ischar( file )
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end

