function [ ] = plotPollutionDist( file, p, xlimits, ylimits, bins )
% plotPollutionDist  Plot histogram of pollution readings.
% file      : filename in which to print or 1 to indicate print to screen
% p         : pollution readings
    
%% Formatting options
textProp = {'fontsize'    , 18, ...
            'FontName'    , 'Arial'};
labProp  = {'fontsize'    , 14, ...
            'FontName'    , textProp{4}};
      
%% Prepare data
p      = exp(p);
ptrunc = quantile(p,0.99);
p      = p(p <= ptrunc);
        
top    = xlimits(2);
width  = 0.5;
bc     = [width/2:width:top-width/2];
pcount = histc(p,[0:width:top]);
pcount = pcount(1:end-1);
pfreq  = pcount / length(p);

%% Main data plot: unconditional cost draws
bar(bc,pcount,'b','BarWidth',1);
%histogram(p,bc);
hold on;

% Figure formatting
xlim(xlimits);
ylim(ylimits);
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off');

% Axis labels
xlabel('Pollution',textProp{:})
ylabel('Number of Plants',textProp{:})   

hold off;

%% Export figure to file
if ischar( file )
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end


