function [ ] = plotTreatByBin( file, p, TI, X1 )
% plotInspectionTargeting  Plot relationship of inspection targeting to 
%   unobservd pollution error.
%
%  Author  : Maddie McKelway
%               Revisions by Nick Ryan
%  Date    : 5 Aug, 2015
%  Project : Analysis of GPCB inspection intervention.
%
% INPUTS:
%   file   : filename in which to print or 1 to indicate print to screen
%   p      : pollution variable for left-hand side
%   TI     : inspection treatment status
%   X1     : design matrix excluding treatment status



%% Assign each reading to a bin 
bin = zeros(length(p),12);
i = 1;
for topbin=-6:2:16;
    bin(:,i) = ((topbin/10)-.2)<p & p<=(topbin/10);
    i = i+1;
end;
clear i;

%% Get regression coefficients for pollution belonging to each bin
X       = [TI X1]; 
beta    = zeros(1,12);
CIupper = zeros(1,12);

for i = 1:12;
    y = bin(:,i);
    [ b, bint ] = regress(y,X);
        %bint gets 95% CI around beta
        %eventually will need to cluster SE's by gpcbid if n=4168
    beta(1,i)    = b(1,1);
    CIupper(1,i) = bint(1,2);
end
clear i b bint x Y;

%% Graph options
textProp = {'fontsize'    , 18, ...
            'FontName'    , 'Arial'};
labProp  = {'fontsize'    , 14, ...
            'FontName'    , textProp{4}};

%% Graph regression coefficients 
x = zeros(1,12);
i = -0.7;
for j=1:1:12
    x(1,j)=i;
    i=i+0.2;
end
clear i;
CI=CIupper-beta;

hold on;
bar(x,beta,'b','BarWidth',1);

errorbar(x,beta,CI,'.','Color','k');
ylim([-0.06 0.08]);



% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}     , ...
         'Box'           , 'off', ...
         'YTick'         , [-0.06:0.02:0.08] );

xlabel('Pollution in standard deviations relative to regulatory limit',...
    textProp{:});
ylabel('Inspection treatment coefficient in bin',textProp{:});
hold off;
       
%% Export figure to file
if ischar( file )
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end