function [ ] = tabCalibrationInspections( fid, EI, sigc, rho )
% Print table of data in a nicely-formatted manner
%   fid      : file id to which to write table contents
%   theta    : vector of coefficients
%   se       : vector of standard errors
%   sigc     : sigma_c parameter with which estimates run
%   rho      : rho parameters with which estimates run


% fid = fopen(fname, 'w');

% Create format strings 

formatSigma   = ['%15s',repmat(' & %3.2f',1,5), '\\\\ \n'];
formatNumbers = [repmat('& (%1d)',1,5), '\\\\ \n'];
formatBody    = ['%15s',repmat(' &  %4.3f ', 1, 5), '\\\\ \n'];

fprintf(fid,'%s\n','\begin{table}[ht] \centering');
fprintf(fid,'%s\n','\caption{Robustness of Expected Inspections to Calibration}');
fprintf(fid,'%s\n','\begin{tabular*}{0.9\hsize}{l*{1}{ccccc}}');
fprintf(fid,'%s\n','\toprule'  );

rowHeads = {'$\mathbb{E}[Inspections]$',...
            '$\mathbb{E}[Inspections^2]$'};

% Column headers
fprintf(fid, formatSigma, '$\sigma_c =$', sigc);
fprintf(fid, formatSigma, '$\rho =$'    , rho);
fprintf(fid, formatNumbers,1:5);
fprintf(fid, '\\midrule \n');

% Table body
R = size(EI,1);
for r = 1:R
    
    fprintf(fid, formatBody, rowHeads{r}, EI(r,:) );

end

fprintf(fid,'%s \n', '\bottomrule' );
fprintf(fid,'%s \n', ['\multicolumn{6}{p{0.88\hsize}}{',...
    'The table reports estimates of the targeting stage of the model.}']);
fprintf(fid,'%s \n', '\end{tabular*}' );
fprintf(fid,'%s \n', '\end{table}' );

end

