function [ ] = tabCalibrationSensitivity( fid, theta, se, sigc, rho )
% Print table of data in a nicely-formatted manner
%   fid      : file id to which to write table contents
%   theta    : vector of coefficients
%   se       : vector of standard errors
%   sigc     : sigma_c parameter with which estimates run
%   rho      : rho parameters with which estimates run


% fid = fopen(fname, 'w');

% Create format strings 

formatHeaders = ['\n \n  %15s',repmat('& %15s',1,8),'\\\\ \n'];
formatSigma   = ['%15s',repmat(' & %3.2f',1,5), '\\\\ \n'];
formatNumbers = [repmat('& (%1d)',1,5), '\\\\ \n'];
formatBody    = ['%15s',repmat(' &  %4.3f ', 1, 5), '\\\\ \n',...
                 '    ',repmat(' & (%4.3f)', 1, 5), '\\\\ \n'];

fprintf(fid,'%s\n','\begin{table}[ht] \centering');
fprintf(fid,'%s\n','\caption{Robustness of Targeting Parameters to Calibration}');
fprintf(fid,'%s\n','\begin{tabular*}{0.9\hsize}{l*{1}{ccccc}}');
fprintf(fid,'%s\n','\toprule'  );

rowHeads = {'Audit treatment',...
            'Audit $\times$ inspection treatment',...
            'Audit sample',...
            'Region: Ahmedabad',...
            'Region: Surat',...
            'Inspection treatment',...
            'Constant',...
            'Audit treatment',...
            'Audit $\times$ inspection treatment',...
            'Audit sample',...
            'Region: Ahmedabad',...
            'Region: Surat',...
            'Run',...
            '$\mu_c$',...
            '$\sigma_1$',...
            '$\sigma_2$',...
            '$\lambda_1$',...
            '$\lambda_2$'};

% colHeadsS = {'Baseline', '$\lambda_2$', '$\sigma_2$', '$\mu_c$'};
 
% Column headers
% fprintf(fid, formatHeaders, colHeadsS{:});
fprintf(fid, formatSigma, '$\sigma_c =$', sigc);
fprintf(fid, formatSigma, '$\rho =$'    , rho);
fprintf(fid, formatNumbers,1:5);
fprintf(fid, '\\midrule \n');

% Table body
R = size(theta,1);
for r = 1:R
    
    fprintf(fid, formatBody, rowHeads{r}, theta(r,:), se(r,:) );

end

fprintf(fid,'%s \n', '\bottomrule' );
fprintf(fid,'%s \n', ['\multicolumn{6}{p{0.88\hsize}}{',...
    'The table reports estimates of the targeting stage of the model.}']);
fprintf(fid,'%s \n', '\end{tabular*}' );
fprintf(fid,'%s \n', '\end{table}' );

end

