function [ ] = tabTargetCoefs( fid, file, title, rowHeads, truth, theta, se, chgUnits )
% Print table of data in a nicely-formatted manner
%   fid      : file id to which to write table contents
%   title    : string with table heading
%   rowHeads : cell array of row headings, often group or id variables
%   theta    : vector of coefficients
%   se       : vector of standard errors
%   chgUnits : 

% Check format string and apply default
formatH = ['%15s ',repmat('%15s ',1,2),'\n'];
format1 = repmat('%15s %15.3f %15.3f (%4.3f)',1,1);

% Title of table
if ~iscell( title )
    fprintf(fid,'\n%40s\n',title);
else
    fprintf(fid,'\n');
    for t = 1:length(title)
        fprintf(fid,'%40s\n',title{t});
    end
end

% First column headings
colHeads = {'','truth','estimate'};
fprintf(fid,formatH,colHeads{:});

% Coefficient block
R = length(theta);
for r = 1:R
    fprintf(fid,[format1,'\n'],rowHeads{r},...
                               truth(r),theta(r),se(r));
end

% Write select coefficients to tex table
keepInsp   = [ 6 17 18 15 16 14 ];
keepPoll   = [ 13 7 ];

thetaInsp = theta(keepInsp);
seInsp    = se(keepInsp);
rowHdInsp = rowHeads(keepInsp);
thetaPoll = theta(keepPoll);
sePoll    = se(keepPoll);
rowHdPoll = rowHeads(keepPoll);
rowHdBoth = cell([rowHdInsp rowHdPoll])';

rowHdBoth = reshape([rowHdBoth(:) repmat({' '},length(rowHdBoth),1)]', ...
                    2*size(rowHdBoth,1), []);

thetaTabInsp = reshape([thetaInsp(:) seInsp(:)]',2*size(thetaInsp,1), []);
thetaTabPoll = reshape([thetaPoll(:) sePoll(:)]',2*size(thetaPoll,1), []);
thetaTab = [ [ thetaTabInsp zeros(size(thetaTabInsp)) ]; ...
             [ zeros(size(thetaTabPoll)) thetaTabPoll  ] ];

fid    = fopen(file,'w');
format = ['%15s',repmat('\t%10.3f',1,size(thetaTab,2))];
tabLatex( fid, title, {'','(1)','(2)'}, ...
             rowHdBoth, thetaTab, format )
fclose(fid);     

fprintf(1,'Saved table  : %s\n', file);
fprintf(1,'In directory : %s\n', pwd);


end

