function [ Is ] = targetPhiFun( lambda, sig1, rho )
%targetPhiFun Step-like function for inspection targeting given parameters
%             based on normal CDF.
%   
% INPUT:
%   lambda - {beta_0,beta_3} parameters defining step-like function for 
%          inspection targeting rule. 
%   sig1 - Standard deviation of observable pollution shock.
%   rho  - Fraction of standard deviation of observable pollution, giving
%          the smoothness of the targeting rule. sigT = rho*sig1.
% Given these parameters, the inspections given to
%   any plant as a function of its pollution shock u_1 are :
%         I(u_1;x) = beta_3 * Phi( (u_1 - beta_0) / (rho*sig1) ) 
%
% OUTPUT: 
%   Is - function handle for targeting function.

% Is = @(u) lambda(2) * normcdf( u, -lambda(1), rho*sig1 );
Is = @(u) lambda(2) * normcdf( u, -lambda(1), rho );

end


