function [ beta, phi, muc, sigma, lambda, gamma ] = ...
    unpackThetaV3( theta, chgUnits, signs, lengths )
%unpackTheta Break parameters into separate vectors
%  Modified for targetingMonteCarlo with change in parameter order
%   
% INPUTS:
%   theta - single parameter vector
%   chgUnits - whether to change units or not

%
% OUTPUTS:
%   
%   beta  - inspection parameters
%   phi   - pollution parameters
%   muc   - mean of log cost distribution
%   sigma - {sigma1 sigma2 sigmac} standard errors of shocks
%   lambda - targeting rule parameters
%   gamma  - Lagrange multiplier on budget constraint

% Adjust for length of beta and phi vectors
lbeta = lengths(1);
lphi  = lengths(2);
lmuc  = lengths(3);
lsig  = lengths(4);
% lrho  = lengths(5);
lrho  = 0;
llam  = lengths(5);
lgam  = 1;

% lbeta =  9;
% lphi  = 10;
% lmuc  =  1;
% lsig  =  3;
% lrho  =  0;
% llam  =  2;
% lgam  =  1;

% Exponentiate to transform parameters to original units
if isempty( chgUnits )
    chgUnits = 1;
end

if chgUnits
    theta = changeThetaVars( theta, signs, 0 );
end

% Unpack parameters
beta   = theta(1:lbeta);
phi    = theta(lbeta+1:lbeta+lphi);
muc    = theta(lbeta+lphi+1);

sigs   = lbeta + lphi + lmuc + 1;
sigma  = theta(sigs:sigs+lsig-1); 
% sigma  = [ theta(sigs+1:sigs+2); theta(sigs) ]; 
% rho    = theta(sigs+lsig);

lambda = theta(sigs+lsig+lrho:sigs+lsig+lrho+llam-1);

% Gamma is either in last position (constrained estimation) or not used at
%   all (unconstrained estimation). Assign to last position in either case,
%   since gamma has no influence on unconstrained estimation.
gamma  = theta(end); 


end